@@ -10,7 +10,7 @@ class Fetch():
         }
         self.headers.update(headers)
 
-    def json(self, test_id: str='200518_Y2_c736f1cb25d54ac8cd93ebdfdcf6375b') -> dict:
+    def json(self, test_id: str='200518_Y2_c736f1cb25d54ac8cd93ebdfdcf6375b', WPT_URI: str = None) -> dict:
         """Fetches the JSON format result for a WPT test
 
         Keyword Arguments:
@@ -20,7 +20,7 @@ class Fetch():
             dict -- json response of the WPT test
         """
         # api rejects the request with unauthorized if user-agent header not set
-        url = '{0}/jsonResult.php?test={1}'.format(WPTParser().WPT_URI(), test_id)
+        url = '{0}/jsonResult.php?test={1}'.format(WPTParser().WPT_URI(WPT_URI), test_id)
         json_data = requests.get(url, headers = self.headers)
         json_data = json_data.json()
         return json_data
\ No newline at end of file
